diff --git a/src/slurmctld/partition_mgr.c b/src/slurmctld/partition_mgr.c
index ab597641df369f1bb52bc1dda530f20fce9b4d93..8a58c601a0c5945d05f366793310a935a5d8dbe1 100644
--- a/src/slurmctld/partition_mgr.c
+++ b/src/slurmctld/partition_mgr.c
@@ -826,22 +826,22 @@ int update_part(update_part_msg_t * part_desc)
  * validate_group - validate that the submit uid is authorized to run in 
  *	this partition
  * IN part_ptr - pointer to a partition
  * IN submit_uid - user submitting the job
  * RET 1 if permitted to run, 0 otherwise
  */
-int validate_group(struct part_record *part_ptr, uid_t submit_uid)
+extern int validate_group(struct part_record *part_ptr, uid_t run_uid)
 {
 	int i;
 
 	if (part_ptr->allow_groups == NULL)
 		return 1;	/* all users allowed */
-	if ((submit_uid == 0) || (submit_uid == getuid()))
+	if ((run_uid == 0) || (run_uid == getuid()))
 		return 1;	/* super-user can run anywhere */
 
 	if (part_ptr->allow_uids == NULL)
 		return 0;	/* no non-super-users in the list */
 	for (i = 0; part_ptr->allow_uids[i]; i++) {
-		if (part_ptr->allow_uids[i] == submit_uid)
+		if (part_ptr->allow_uids[i] == run_uid)
 			return 1;
 	}
 	return 0;		/* not in this group's list */
@@ -826,22 +826,22 @@ int update_part(update_part_msg_t * part_desc)
  *	this partition
  * IN part_ptr - pointer to a partition
- * IN submit_uid - user submitting the job
+ * IN run_uid - user to run the job as
  * RET 1 if permitted to run, 0 otherwise
  */
diff --git a/src/slurmctld/slurmctld.h b/src/slurmctld/slurmctld.h
index 4204db440260d3f8462fa7d6d5f6caf6b6ec9a27..720dc1a21d42111b1289de540a39b3d6b97836b4 100644
--- a/src/slurmctld/slurmctld.h
+++ b/src/slurmctld/slurmctld.h
@@ -1093,10 +1093,10 @@ extern int update_part (update_part_msg_t * part_desc );
  * validate_group - validate that the submit uid is authorized to run in 
  *	this partition
  * IN part_ptr - pointer to a partition
  * IN submit_uid - user submitting the job
  * RET 1 if permitted to run, 0 otherwise
  */
-extern int validate_group (struct part_record *part_ptr, uid_t submit_uid);
+extern int validate_group (struct part_record *part_ptr, uid_t run_uid);
 
 /*
  * validate_jobs_on_node - validate that any jobs that should be on the node
@@ -1093,10 +1093,10 @@ extern int update_part (update_part_msg_t * part_desc );
  *	this partition
  * IN part_ptr - pointer to a partition
- * IN submit_uid - user submitting the job
+ * IN run_uid - user to run the job as
  * RET 1 if permitted to run, 0 otherwise
  */